@@ -73,57 +73,83 @@ class FrequencyTestCase(unittest.TestCase):
         self.assertEqual(self.job.frequency_per_year(year=2013), 11)
         self.assertEqual(self.job.frequency_per_year(year=2010), 12)
 
-
-    def test_01_job(self):
+    def test_03_job(self):
         """Once Yearly"""
         self.job.setall("0 0 1 1 *")
         self.assertEqual(self.job.frequency(year=2010), 1)
 
-    def test_02_twice(self):
+    def test_04_twice(self):
         """Twice Yearly"""
         self.job.setall("0 0 1 1,6 *")
         self.assertEqual(self.job.frequency(year=2010), 2)
 
-    def test_03_thrice(self):
+    def test_05_thrice(self):
         """Thrice Yearly"""
         self.job.setall("0 0 1 1,3,6 *")
         self.assertEqual(self.job.frequency(year=2010), 3)
 
-    def test_04_quart(self):
+    def test_06_quart(self):
         """Four Yearly"""
         self.job.setall("0 0 1 */3 *")
         self.assertEqual(self.job.frequency(year=2010), 4)
 
-    def test_05_monthly(self):
+    def test_07_monthly(self):
         """Once a month"""
         self.job.setall("0 0 1 * *")
         self.assertEqual(self.job.frequency(year=2010), 12)
 
-    def test_06_six_monthly(self):
+    def test_08_six_monthly(self):
         """Six a month"""
         self.job.setall("0 0 1,2,3,4,5,6 * *")
         self.assertEqual(self.job.frequency(year=2010), 72)
 
-    def test_07_every_day(self):
+    def test_09_every_day(self):
         """Every Day"""
         self.job.setall("0 0 * * *")
         self.assertEqual(self.job.frequency(year=2010), 365)
 
-    def test_08_every_hour(self):
+    def test_10_every_hour(self):
         """Every Hour"""
         self.job.setall("0 * * * *")
         self.assertEqual(self.job.frequency(year=2010), 8760)
 
-    def test_08_every_other_hour(self):
+    def test_11_every_other_hour(self):
         """Every Other Hour"""
         self.job.setall("0 */2 * * *")
         self.assertEqual(self.job.frequency(year=2010), 4380)
 
-    def test_08_every_minute(self):
+    def test_12_every_minute(self):
         """Every Minute"""
         self.job.setall("* * * * *")
         self.assertEqual(self.job.frequency(year=2010), 525600)
 
+    def test_13_enum(self):
+        """Enumerations"""
+        self.job.setall("0 0 * * MON-WED")
+        self.assertEqual(self.job.frequency(year=2010), 156)
+        self.job.setall("0 0 * JAN-MAR *")
+        self.assertEqual(self.job.frequency(year=2010), 90)
+
+    def test_14_all(self):
+        """Test Maximum"""
+        self.job.setall("* * * * *")
+        self.assertEqual(self.job.frequency(), 525600)
+        self.assertEqual(self.job.frequency_per_year(year=2010), 365)
+        self.assertEqual(self.job.frequency_per_day(), 1440)
+        self.job.setall("*")
+        self.assertEqual(self.job.frequency_per_day(), 1440)
+        self.assertEqual(self.job.frequency_per_year(year=2010), 365)
+        self.assertEqual(self.job.frequency(), 525600)
+
+    def test_15_compare(self):
+        """Compare Times"""
+        job = self.crontab.new(command='match')
+        job.setall("*/2 * * * *")
+        self.assertEqual( job.slices, "*/2 * * * *" )
+        self.assertEqual( job.slices, ["*/2"] )
+        self.assertLess( job, ["*"] )
+        self.assertGreater( job, "*/3" )
+
 
 if __name__ == '__main__':
     test_support.run_unittest(
